# Cassini

A virtual lab-book framework, using Jupyter Lab and Python. 

### Installation

1. `pip install cassini`
2. Install ``ipywidgets`` Jupyter Lab extension ``conda install -c conda-forge nodejs`` then
``jupyter labextension install @jupyter-widgets/jupyterlab-manager``

Try it: [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/0Hughman0/Cassini/master?urlpath=lab%2Ftree%2Fexamples%2Fdefault%2F)

Head to [Quickstart](https://0hughman0.github.io/Cassini/quickstart.html) to get going.

# Todo:

Make a Jupyter extension that adds a new thing to the launcher, which is basically recreating the home header.

Make use of tabulator to render the tables.

Get it so all links open new tabs if control click, and just navigate without.

Create a jupyter server extension that serves up the json for the above.

Not sure how that'd work with the creation widgets hmmm.